@@ -313,7 +313,28 @@ class ImagePipeline(
         :param subnet_id: Subnet ID for the Infrastructure Configuration.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ImagePipeline.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                component_documents: typing.Sequence[builtins.str],
+                component_names: typing.Sequence[builtins.str],
+                component_versions: typing.Sequence[builtins.str],
+                image_recipe: builtins.str,
+                infra_config_name: builtins.str,
+                kms_key_alias: builtins.str,
+                parent_image: builtins.str,
+                pipeline_name: builtins.str,
+                profile_name: builtins.str,
+                email: typing.Optional[builtins.str] = None,
+                image_recipe_version: typing.Optional[builtins.str] = None,
+                instance_types: typing.Optional[typing.Sequence[builtins.str]] = None,
+                platform: typing.Optional[builtins.str] = None,
+                security_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
+                subnet_id: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ImagePipelineProps(
@@ -349,7 +370,11 @@ class ImagePipeline(
         value: typing.List[aws_cdk.aws_imagebuilder.CfnImageRecipe.ComponentConfigurationProperty],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(ImagePipeline, "image_recipe_components").fset)
+            def stub(
+                value: typing.List[aws_cdk.aws_imagebuilder.CfnImageRecipe.ComponentConfigurationProperty],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "imageRecipeComponents", value)
 
@@ -413,7 +438,26 @@ class ImagePipelineProps:
         :param subnet_id: Subnet ID for the Infrastructure Configuration.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ImagePipelineProps.__init__)
+            def stub(
+                *,
+                component_documents: typing.Sequence[builtins.str],
+                component_names: typing.Sequence[builtins.str],
+                component_versions: typing.Sequence[builtins.str],
+                image_recipe: builtins.str,
+                infra_config_name: builtins.str,
+                kms_key_alias: builtins.str,
+                parent_image: builtins.str,
+                pipeline_name: builtins.str,
+                profile_name: builtins.str,
+                email: typing.Optional[builtins.str] = None,
+                image_recipe_version: typing.Optional[builtins.str] = None,
+                instance_types: typing.Optional[typing.Sequence[builtins.str]] = None,
+                platform: typing.Optional[builtins.str] = None,
+                security_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
+                subnet_id: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument component_documents", value=component_documents, expected_type=type_hints["component_documents"])
             check_type(argname="argument component_names", value=component_names, expected_type=type_hints["component_names"])
             check_type(argname="argument component_versions", value=component_versions, expected_type=type_hints["component_versions"])
